@@ -571,6 +571,19 @@ def convert_lims_path(path):
 
 
 def convert_path_str_to_pathlib(data_dict_orig) -> dict:
+    """
+    >>> orig = {0: '\\\\allen\\programs\\mindscope'}
+    >>> test = convert_path_str_to_pathlib(orig)
+    >>> test[0].as_posix()
+    '//allen/programs/mindscope'
+    
+    >>> test[0] != orig[0]
+    True
+    
+    >>> test = convert_path_str_to_pathlib({1: '/allen/programs/mindscope'})
+    >>> test[1].as_posix()
+    '//allen/programs/mindscope'
+    """
     data_dict = data_dict_orig.copy()
     for k, v in data_dict.items():
         if isinstance(v, str) and (v.startswith("/") or v.startswith("\\")):
@@ -579,3 +592,7 @@ def convert_path_str_to_pathlib(data_dict_orig) -> dict:
                 v = "/" + v
             data_dict[k] = pathlib.Path(v)
     return data_dict
+
+if __name__ == "__main__":
+    import doctest
+    doctest.testmod()
\ No newline at end of file
